# copia
Bias correction for richness in abundance data

For development, run 

``` bash
pip install -e . 
```

in the top directory of `copia`.

Subsequently, run `pytest` from the same directory. 

## Etymology
The package is named after the Latin term for "abundance".
